@@ -8,7 +8,6 @@
 
 #include <KCModule>
 
-#include "kcmutils_version.h"
 #include <QVariant>
 namespace KUserFeedback
 {
@@ -21,11 +20,7 @@ class KCMKaddressbookUserFeedBackConfig : public KCModule
 {
     Q_OBJECT
 public:
-#if KCMUTILS_VERSION < QT_VERSION_CHECK(5, 240, 0)
-    explicit KCMKaddressbookUserFeedBackConfig(QWidget *parent, const QVariantList &args);
-#else
-    explicit KCMKaddressbookUserFeedBackConfig(QObject *parent, const KPluginMetaData &data, const QVariantList &args);
-#endif
+    explicit KCMKaddressbookUserFeedBackConfig(QObject *parent, const KPluginMetaData &data);
     void load() override;
     void save() override;
     void defaults() override;
